<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../../includes/auth.php';
require_once '../../includes/functions.php';
requireLocationAdmin();

$locationId = getCurrentUserLocationId();
$location = getLocationById($locationId);

// Generate the registration link using the getJoinUrl function
$registrationLink = getJoinUrl($location['slug']);

// Handle regenerate slug if needed
$message = '';
$messageType = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['regenerate_slug'])) {
    // Generate a new unique slug
    $newSlug = generateUniqueSlug($location['name']);
    
    // Update the location with the new slug
    $conn = getDbConnection();
    $stmt = $conn->prepare("UPDATE locations SET slug = :slug WHERE id = :id");
    $stmt->bindParam(':slug', $newSlug);
    $stmt->bindParam(':id', $locationId);
    
    if ($stmt->execute()) {
        $message = "Registration link updated successfully!";
        $messageType = "success";
        
        // Update the location data and registration link
        $location = getLocationById($locationId);
        $registrationLink = getJoinUrl($location['slug']);
    } else {
        $message = "Failed to update registration link";
        $messageType = "error";
    }
}

// Function to generate a unique slug
function generateUniqueSlug($name) {
    $conn = getDbConnection();
    
    // Convert name to lowercase and replace spaces with hyphens
    $baseSlug = strtolower(str_replace(' ', '-', $name));
    $baseSlug = preg_replace('/[^a-z0-9-]/', '', $baseSlug);
    
    // Check if the slug already exists
    $slug = $baseSlug;
    $counter = 1;
    
    while (true) {
        $stmt = $conn->prepare("SELECT COUNT(*) FROM locations WHERE slug = :slug");
        $stmt->bindParam(':slug', $slug);
        $stmt->execute();
        
        if ($stmt->fetchColumn() == 0) {
            break;
        }
        
        $slug = $baseSlug . '-' . $counter;
        $counter++;
    }
    
    return $slug;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registration Link - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
</head>
<body class="bg-gray-100 min-h-screen">
    <!-- Navigation -->
    <nav class="bg-blue-600 text-white p-4">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-xl font-bold">Pointify</h1>
            <div class="flex items-center space-x-4">
                <a href="dashboard.php" class="hover:underline">Dashboard</a>
                <span>Welcome, <?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                <a href="../logout.php" class="bg-blue-700 px-3 py-1 rounded hover:bg-blue-800">Logout</a>
            </div>
        </div>
    </nav>
    
    <!-- Main Content -->
    <div class="container mx-auto p-4">
        <div class="bg-white rounded-lg shadow-md p-6 mb-6">
            <h2 class="text-2xl font-bold mb-4">Registration Link</h2>
            
            <?php if ($message): ?>
                <div class="<?php echo $messageType === 'error' ? 'bg-red-100 border-red-400 text-red-700' : 'bg-green-100 border-green-400 text-green-700'; ?> px-4 py-3 rounded mb-4 border">
                    <?php echo htmlspecialchars($message); ?>
                </div>
            <?php endif; ?>
            
            <p class="mb-6">Share this link with your customers to allow them to register for your loyalty program:</p>
            
            <div class="bg-gray-100 p-4 rounded-lg mb-6 relative">
                <p id="registration-link" class="break-all font-mono text-sm"><?php echo htmlspecialchars($registrationLink); ?></p>
                <button id="copy-button" class="absolute top-2 right-2 bg-blue-500 text-white py-1 px-3 rounded hover:bg-blue-600 transition duration-200">
                    <i class="fas fa-copy mr-1"></i> Copy
                </button>
            </div>
            
            <div class="bg-blue-50 p-4 rounded-lg border border-blue-200 mb-6">
                <h3 class="text-lg font-semibold text-blue-700 mb-2">How It Works</h3>
                <ol class="list-decimal pl-5 space-y-2">
                    <li>Share this registration link with your customers</li>
                    <li>Customers click the link and fill out the registration form</li>
                    <li>They verify their email with a one-time password</li>
                    <li>After verification, they receive their digital loyalty card</li>
                    <li>Use the "Scan Barcode" feature to add stamps when they make purchases</li>
                </ol>
            </div>
        </div>
        
        <div class="bg-white rounded-lg shadow-md p-6">
            <h2 class="text-2xl font-bold mb-4">Promotional Materials</h2>
            
            <div class="mb-6">
                <p>Use these templates to promote your loyalty program:</p>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                <div class="border rounded-lg overflow-hidden">
                    <div class="bg-gray-200 p-4">
                        <h3 class="font-semibold">Email Template</h3>
                    </div>
                    <div class="p-4">
                        <div class="bg-gray-50 p-4 rounded border mb-4">
                            <p><strong>Subject:</strong> Join Our Loyalty Program and Earn Rewards!</p>
                            <hr class="my-2">
                            <p>Dear Customer,</p>
                            <p class="my-2">We're excited to invite you to join our loyalty program! Earn stamps with every purchase and receive rewards when you collect enough stamps.</p>
                            <p class="my-2">Register now using this link: <span class="text-blue-500"><?php echo htmlspecialchars($registrationLink); ?></span></p>
                            <p class="my-2">Thank you for your continued support!</p>
                            <p>Best regards,<br><?php echo htmlspecialchars($location['name']); ?> Team</p>
                        </div>
                        <button class="copy-template-btn bg-blue-500 text-white py-1 px-3 rounded hover:bg-blue-600 transition duration-200" data-template="email">
                            <i class="fas fa-copy mr-1"></i> Copy Template
                        </button>
                    </div>
                </div>
                
                <div class="border rounded-lg overflow-hidden">
                    <div class="bg-gray-200 p-4">
                        <h3 class="font-semibold">Social Media Post</h3>
                    </div>
                    <div class="p-4">
                        <div class="bg-gray-50 p-4 rounded border mb-4">
                            <p>🎁 Join our loyalty program and start earning rewards today! 🎁</p>
                            <p class="my-2">How it works:</p>
                            <p>✅ Register using the link below<br>
                            ✅ Get a digital loyalty card<br>
                            ✅ Earn stamps with every purchase<br>
                            ✅ Collect <?php echo htmlspecialchars($location['reward_threshold']); ?> stamps for a free reward!</p>
                            <p class="my-2">Register now: <?php echo htmlspecialchars($registrationLink); ?></p>
                            <p>#loyalty #rewards #<?php echo htmlspecialchars(str_replace(' ', '', $location['name'])); ?></p>
                        </div>
                        <button class="copy-template-btn bg-blue-500 text-white py-1 px-3 rounded hover:bg-blue-600 transition duration-200" data-template="social">
                            <i class="fas fa-copy mr-1"></i> Copy Template
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Copy registration link
            const copyButton = document.getElementById('copy-button');
            const registrationLink = document.getElementById('registration-link');
            
            copyButton.addEventListener('click', function() {
                const tempTextArea = document.createElement('textarea');
                tempTextArea.value = registrationLink.textContent;
                document.body.appendChild(tempTextArea);
                tempTextArea.select();
                document.execCommand('copy');
                document.body.removeChild(tempTextArea);
                
                // Change button text temporarily
                const originalText = copyButton.innerHTML;
                copyButton.innerHTML = '<i class="fas fa-check mr-1"></i> Copied!';
                copyButton.classList.remove('bg-blue-500', 'hover:bg-blue-600');
                copyButton.classList.add('bg-green-500', 'hover:bg-green-600');
                
                setTimeout(function() {
                    copyButton.innerHTML = originalText;
                    copyButton.classList.remove('bg-green-500', 'hover:bg-green-600');
                    copyButton.classList.add('bg-blue-500', 'hover:bg-blue-600');
                }, 2000);
            });
            
            // Copy templates
            const copyTemplateButtons = document.querySelectorAll('.copy-template-btn');
            
            copyTemplateButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const templateType = this.getAttribute('data-template');
                    const templateContainer = this.previousElementSibling;
                    
                    const tempTextArea = document.createElement('textarea');
                    tempTextArea.value = templateContainer.textContent;
                    document.body.appendChild(tempTextArea);
                    tempTextArea.select();
                    document.execCommand('copy');
                    document.body.removeChild(tempTextArea);
                    
                    // Change button text temporarily
                    const originalText = this.innerHTML;
                    this.innerHTML = '<i class="fas fa-check mr-1"></i> Copied!';
                    this.classList.remove('bg-blue-500', 'hover:bg-blue-600');
                    this.classList.add('bg-green-500', 'hover:bg-green-600');
                    
                    setTimeout(() => {
                        this.innerHTML = originalText;
                        this.classList.remove('bg-green-500', 'hover:bg-green-600');
                        this.classList.add('bg-blue-500', 'hover:bg-blue-600');
                    }, 2000);
                });
            });
        });
    </script>
</body>
</html> 