<?php
// Make sure there's no whitespace or output before this opening PHP tag
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include both functions.php and auth.php to ensure all required functions are available
require_once '../includes/functions.php';
require_once '../includes/auth.php';

// Check if already logged in
if (checkUserSession()) {
    redirectToDashboard();
}

$error = '';

// Process login form
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = $_POST['username'] ?? '';
    $password = $_POST['password'] ?? '';
    
    if (empty($username) || empty($password)) {
        $error = "Please enter both username and password";
    } else {
        $user = authenticateUser($username, $password);
        
        if ($user) {
            // Start session if not already started
            if (session_status() == PHP_SESSION_NONE) {
                session_start();
            }
            
            // Set session variables
            $_SESSION['user_id'] = $user['id'];
            $_SESSION['user_name'] = $user['name'];
            $_SESSION['user_role'] = $user['role'];
            
            // Set location_id for location admins
            if ($user['role'] === 'location_admin') {
                $_SESSION['location_id'] = $user['location_id'];
            }
            
            // Debug information
            error_log("Login successful for user: " . $username);
            error_log("Session variables: " . print_r($_SESSION, true));
            
            // Redirect based on role
            redirectToDashboard();
        } else {
            $error = "Invalid username or password";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Login - Pointify</title>
    <!-- Modern CSS framework -->
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Poppins', sans-serif;
        }
        .login-container {
            background: linear-gradient(135deg, #f5f7fa 0%, #c3cfe2 100%);
        }
        .card {
            backdrop-filter: blur(10px);
            background-color: rgba(255, 255, 255, 0.9);
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
        }
        .input-group {
            position: relative;
        }
        .input-icon {
            position: absolute;
            left: 1rem;
            top: 50%;
            transform: translateY(-50%);
            color: #6B7280;
        }
        .input-field {
            padding-left: 2.5rem !important;
            transition: all 0.3s ease;
        }
        .input-field:focus {
            border-color: #3B82F6;
            box-shadow: 0 0 0 3px rgba(59, 130, 246, 0.3);
        }
        .btn-login {
            background: linear-gradient(135deg, #4F46E5 0%, #3B82F6 100%);
            transition: all 0.3s ease;
        }
        .btn-login:hover {
            transform: translateY(-2px);
            box-shadow: 0 4px 12px rgba(59, 130, 246, 0.4);
        }
        .logo-container {
            animation: float 3s ease-in-out infinite;
        }
        @keyframes float {
            0% { transform: translateY(0px); }
            50% { transform: translateY(-10px); }
            100% { transform: translateY(0px); }
        }
    </style>
</head>
<body class="login-container min-h-screen flex items-center justify-center p-4">
    <div class="w-full max-w-md">
        <div class="text-center mb-8 logo-container">
            <div class="inline-block p-4 rounded-full bg-white shadow-lg mb-4">
                <i class="fas fa-id-card text-5xl text-blue-600"></i>
            </div>
            <h1 class="text-3xl font-bold text-gray-800">Pointify</h1>
            <p class="text-gray-600 mt-2">Admin Portal</p>
        </div>
        
        <div class="card rounded-xl p-8">
            <h2 class="text-2xl font-semibold text-center mb-6 text-gray-800">Sign In</h2>
            
            <?php if ($error): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-6 rounded-md flex items-center">
                    <i class="fas fa-exclamation-circle mr-3"></i>
                    <span><?php echo htmlspecialchars($error); ?></span>
                </div>
            <?php endif; ?>
            
            <form method="post" class="space-y-6">
                <div>
                    <label for="username" class="block text-sm font-medium text-gray-700 mb-2">Username</label>
                    <div class="input-group">
                        <i class="fas fa-user input-icon"></i>
                        <input type="text" id="username" name="username" required 
                            class="input-field w-full px-4 py-3 border border-gray-300 rounded-lg focus:outline-none"
                            placeholder="Enter your username">
                    </div>
                </div>
                
                <div>
                    <div class="flex justify-between mb-2">
                        <label for="password" class="block text-sm font-medium text-gray-700">Password</label>
                        <a href="#" class="text-sm text-blue-600 hover:text-blue-800 transition">Forgot password?</a>
                    </div>
                    <div class="input-group">
                        <i class="fas fa-lock input-icon"></i>
                        <input type="password" id="password" name="password" required 
                            class="input-field w-full px-4 py-3 border border-gray-300 rounded-lg focus:outline-none"
                            placeholder="Enter your password">
                    </div>
                </div>
                
                <div class="flex items-center">
                    <input type="checkbox" id="remember" name="remember" class="h-4 w-4 text-blue-600 focus:ring-blue-500 border-gray-300 rounded">
                    <label for="remember" class="ml-2 block text-sm text-gray-700">Remember me</label>
                </div>
                
                <button type="submit" class="btn-login w-full text-white py-3 px-4 rounded-lg font-medium flex items-center justify-center">
                    <i class="fas fa-sign-in-alt mr-2"></i>
                    Sign In
                </button>
            </form>
            
            <div class="mt-6 text-center text-sm text-gray-600">
                <p>Need help? <a href="#" class="text-blue-600 hover:text-blue-800 transition">Contact support</a></p>
            </div>
        </div>
        
        <div class="mt-8 text-center text-sm text-gray-500">
            <p>© <?php echo date('Y'); ?> Pointify. All rights reserved.</p>
        </div>
    </div>
</body>
</html> 