<?php
require_once '../../includes/auth.php';
requireSuperAdmin();

$error = '';
$success = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name'] ?? '');
    $rewardThreshold = intval($_POST['reward_threshold'] ?? 7);
    
    if (empty($name)) {
        $error = "Please enter a location name";
    } else {
        // Generate slug from name
        $slug = generateSlug($name);
        
        // Create location
        $result = createLocation($name, $slug, $rewardThreshold);
        
        if ($result['success']) {
            $success = "Location created successfully!";
        } else {
            $error = $result['message'];
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Create Location - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen">
    <!-- Navigation -->
    <nav class="bg-blue-600 text-white p-4">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-xl font-bold">Pointify</h1>
            <div class="flex items-center space-x-4">
                <a href="dashboard.php" class="hover:underline">Dashboard</a>
                <span>Welcome, <?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                <a href="../logout.php" class="bg-blue-700 px-3 py-1 rounded hover:bg-blue-800">Logout</a>
            </div>
        </div>
    </nav>
    
    <!-- Main Content -->
    <div class="container mx-auto p-4">
        <div class="bg-white rounded-lg shadow-md p-6">
            <h2 class="text-2xl font-bold mb-4">Create New Location</h2>
            
            <?php if ($error): ?>
                <div class="mb-4 p-4 bg-red-100 text-red-700 rounded">
                    <?php echo htmlspecialchars($error); ?>
                </div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="mb-4 p-4 bg-green-100 text-green-700 rounded">
                    <?php echo htmlspecialchars($success); ?>
                </div>
            <?php endif; ?>
            
            <form method="post" class="space-y-4">
                <div>
                    <label for="name" class="block text-gray-700 mb-2">Location Name</label>
                    <input type="text" id="name" name="name" required 
                        class="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                        placeholder="e.g., Cafe X">
                </div>
                
                <div>
                    <label for="reward_threshold" class="block text-gray-700 mb-2">Reward Threshold</label>
                    <input type="number" id="reward_threshold" name="reward_threshold" required min="1" value="7"
                        class="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                        placeholder="Number of stamps required for a reward">
                    <p class="text-sm text-gray-500 mt-1">Number of stamps required for a customer to earn a reward</p>
                </div>
                
                <button type="submit" class="bg-blue-500 text-white py-2 px-4 rounded-lg hover:bg-blue-600 transition duration-200">
                    Create Location
                </button>
            </form>
        </div>
    </div>
</body>
</html> 