<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../../includes/auth.php';
requireSuperAdmin();

// Get database connection from auth.php
global $conn;

// If $conn is still not available, try to establish the connection directly
if (!isset($conn)) {
    // This is a fallback - adjust these values to match your actual database configuration
    $host = 'localhost';
    $username = 'root';
    $password = '';
    $database = 'loyalty_card_system'; // Replace with your actual database name
    
    $conn = mysqli_connect($host, $username, $password, $database);
    
    if (!$conn) {
        die("Database connection failed: " . mysqli_connect_error());
    }
}

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $_SESSION['error_message'] = "Location ID is required";
    header("Location: dashboard.php");
    exit();
}

$location_id = $_GET['id'];
$location = getLocationById($location_id);

// If location doesn't exist, redirect back to dashboard
if (!$location) {
    $_SESSION['error_message'] = "Location not found";
    header("Location: dashboard.php");
    exit();
}

// Get customers for this location
$customers_query = "SELECT * FROM customers WHERE location_id = $location_id ORDER BY created_at DESC";
$customers_result = mysqli_query($conn, $customers_query);
$customers = [];

if ($customers_result) {
    while ($row = mysqli_fetch_assoc($customers_result)) {
        $customers[] = $row;
    }
}

// Count total customers
$total_customers = count($customers);

// Count customers with rewards
$customers_with_rewards = 0;
foreach ($customers as $customer) {
    if (isset($customer['stamp_count']) && $customer['stamp_count'] >= $location['reward_threshold']) {
        $customers_with_rewards++;
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Location - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Inter', sans-serif;
            background-color: #f3f4f6;
        }
        .nav-gradient {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
        }
        .stat-card {
            transition: all 0.3s ease;
            border-radius: 16px;
        }
        .stat-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
        }
        .table-container {
            border-radius: 16px;
            overflow: hidden;
        }
        .table-row-hover:hover {
            background-color: #f5f7ff;
        }
    </style>
</head>
<body class="bg-gray-50 min-h-screen">
    <!-- Navigation -->
    <nav class="nav-gradient text-white p-4 shadow-lg sticky top-0 z-50">
        <div class="container mx-auto flex justify-between items-center">
            <div class="flex items-center space-x-3">
                <i class="fas fa-id-card-alt text-2xl"></i>
                <h1 class="text-xl font-bold">Pointify</h1>
            </div>
            <div class="flex items-center space-x-6">
                <div class="flex items-center space-x-2">
                    <div class="w-8 h-8 rounded-full bg-indigo-400 flex items-center justify-center">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="font-medium"><?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                </div>
                <a href="../logout.php" class="bg-white bg-opacity-20 px-4 py-2 rounded-full hover:bg-opacity-30 transition flex items-center">
                    <i class="fas fa-sign-out-alt mr-2"></i> Logout
                </a>
            </div>
        </div>
    </nav>
    
    <!-- Main Content -->
    <div class="container mx-auto p-6">
        <!-- Location Details -->
        <div class="bg-white rounded-2xl shadow-md p-8 mb-8">
            <div class="flex items-center justify-between mb-6">
                <div class="flex items-center">
                    <a href="dashboard.php" class="text-indigo-600 hover:text-indigo-800 mr-4">
                        <i class="fas fa-arrow-left"></i> Back to Dashboard
                    </a>
                    <h2 class="text-2xl font-bold text-gray-800">Location Details</h2>
                </div>
                <a href="edit_location.php?id=<?php echo $location['id']; ?>" class="bg-indigo-600 hover:bg-indigo-700 text-white px-5 py-2 rounded-xl transition flex items-center">
                    <i class="fas fa-edit mr-2"></i> Edit Location
                </a>
            </div>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-8 mb-8">
                <div class="bg-gray-50 p-6 rounded-xl">
                    <h3 class="text-lg font-semibold text-gray-800 mb-4 border-b pb-2">Basic Information</h3>
                    
                    <div class="space-y-4">
                        <div>
                            <p class="text-sm text-gray-500">Location Name</p>
                            <p class="text-lg font-medium"><?php echo htmlspecialchars($location['name']); ?></p>
                        </div>
                        
                        <div>
                            <p class="text-sm text-gray-500">Slug</p>
                            <p class="text-lg font-medium"><?php echo htmlspecialchars($location['slug']); ?></p>
                        </div>
                        
                        <div>
                            <p class="text-sm text-gray-500">Reward Threshold</p>
                            <div class="flex items-center">
                                <span class="text-lg font-medium mr-2"><?php echo $location['reward_threshold']; ?></span>
                                <span class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-full text-sm">
                                    <i class="fas fa-stamp mr-1"></i> stamps
                                </span>
                            </div>
                        </div>
                    </div>
                </div>
                
                <div class="bg-gray-50 p-6 rounded-xl">
                    <h3 class="text-lg font-semibold text-gray-800 mb-4 border-b pb-2">Statistics</h3>
                    
                    <div class="grid grid-cols-2 gap-4">
                        <div class="bg-white p-4 rounded-lg shadow-sm stat-card">
                            <p class="text-sm text-gray-500 mb-1">Total Customers</p>
                            <p class="text-2xl font-bold text-indigo-600"><?php echo $total_customers; ?></p>
                        </div>
                        
                        <div class="bg-white p-4 rounded-lg shadow-sm stat-card">
                            <p class="text-sm text-gray-500 mb-1">Rewards Eligible</p>
                            <p class="text-2xl font-bold text-green-600"><?php echo $customers_with_rewards; ?></p>
                        </div>
                    </div>
                    
                    <div class="mt-6">
                        <p class="text-sm text-gray-500">Registration Link</p>
                        <div class="flex items-center mt-1">
                            <input type="text" value="<?php echo htmlspecialchars($location['registration_link'] ?? ''); ?>" 
                                   class="w-full px-4 py-2 border border-gray-300 rounded-lg bg-gray-100" readonly>
                            <button onclick="copyToClipboard(this)" data-link="<?php echo htmlspecialchars($location['registration_link'] ?? ''); ?>" 
                                    class="ml-2 bg-gray-200 hover:bg-gray-300 text-gray-700 px-3 py-2 rounded-lg transition">
                                <i class="fas fa-copy"></i>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Customers List -->
            <div class="mt-8">
                <h3 class="text-xl font-semibold text-gray-800 mb-6 flex items-center">
                    <span class="bg-green-100 text-green-600 p-2 rounded-lg mr-3">
                        <i class="fas fa-users"></i>
                    </span>
                    Customers (<?php echo $total_customers; ?>)
                </h3>
                
                <div class="overflow-x-auto table-container shadow-sm border border-gray-200">
                    <table class="min-w-full bg-white">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Name</th>
                                <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Email</th>
                                <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Card Number</th>
                                <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Stamps</th>
                                <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Joined</th>
                                <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($customers as $customer): ?>
                            <tr class="table-row-hover transition">
                                <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['name']); ?></td>
                                <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['email']); ?></td>
                                <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['card_number'] ?? 'N/A'); ?></td>
                                <td class="py-4 px-6 border-b">
                                    <div class="flex items-center">
                                        <?php if (isset($customer['stamp_count']) && $customer['stamp_count'] > 0): ?>
                                        <div class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-full flex items-center">
                                            <span class="mr-1"><?php echo $customer['stamp_count']; ?></span>
                                            <i class="fas fa-stamp text-xs"></i>
                                        </div>
                                        <?php else: ?>
                                        <span class="text-gray-500">0</span>
                                        <?php endif; ?>
                                        
                                        <?php if (isset($customer['stamp_count']) && $customer['stamp_count'] >= $location['reward_threshold']): ?>
                                        <span class="ml-2 bg-yellow-100 text-yellow-600 px-2 py-1 rounded-full text-xs flex items-center">
                                            <i class="fas fa-award mr-1"></i> Reward
                                        </span>
                                        <?php endif; ?>
                                    </div>
                                </td>
                                <td class="py-4 px-6 border-b">
                                    <?php 
                                    if (isset($customer['created_at'])) {
                                        echo date('M d, Y', strtotime($customer['created_at']));
                                    } else {
                                        echo 'N/A';
                                    }
                                    ?>
                                </td>
                                <td class="py-4 px-6 border-b">
                                    <?php if (!empty($customer['card_number'])): ?>
                                    <a href="../../customer/card.php?card_number=<?php echo urlencode($customer['card_number']); ?>" 
                                       class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-lg hover:bg-indigo-200 transition flex items-center w-max" target="_blank">
                                        <i class="fas fa-id-card mr-1"></i> View Card
                                    </a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                            
                            <?php if (empty($customers)): ?>
                            <tr>
                                <td colspan="6" class="py-8 text-center text-gray-500">
                                    <div class="flex flex-col items-center">
                                        <div class="bg-gray-100 p-4 rounded-full mb-3">
                                            <i class="fas fa-user-slash text-3xl text-gray-400"></i>
                                        </div>
                                        <p>No customers found for this location</p>
                                    </div>
                                </td>
                            </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-white py-6 border-t mt-8">
        <div class="container mx-auto px-6 text-center">
            <p class="text-gray-500 text-sm">© <?php echo date('Y'); ?> Pointify. All rights reserved.</p>
        </div>
    </footer>
    
    <script>
        function copyToClipboard(button) {
            const link = button.getAttribute('data-link');
            navigator.clipboard.writeText(link).then(() => {
                // Change button icon temporarily
                const originalHTML = button.innerHTML;
                button.innerHTML = '<i class="fas fa-check"></i>';
                button.classList.add('bg-green-200', 'text-green-700');
                
                setTimeout(() => {
                    button.innerHTML = originalHTML;
                    button.classList.remove('bg-green-200', 'text-green-700');
                }, 2000);
            });
        }
    </script>
</body>
</html> 