<?php
require_once __DIR__ . '/../includes/functions.php';

// Check if card_number parameter is provided
if (!isset($_GET['card_number'])) {
    die("Card number parameter is required");
}

$cardNumber = $_GET['card_number'];

// Get card details
$conn = getDbConnection();
$stmt = $conn->prepare("
    SELECT lc.*, c.name, c.email, l.name as location_name, l.logo_url, l.reward_threshold, l.reward_description
    FROM loyalty_cards lc
    JOIN customers c ON lc.customer_id = c.id
    JOIN locations l ON c.location_id = l.id
    WHERE lc.card_number = :card_number
");
$stmt->bindParam(':card_number', $cardNumber);
$stmt->execute();
$card = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$card) {
    die("Invalid card number");
}

// Generate QR code data for the card
$cardUrl = getCardUrl($cardNumber);
$qrCodeUrl = "https://api.qrserver.com/v1/create-qr-code/?size=200x200&data=" . urlencode($cardUrl);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Apple Wallet Instructions - <?php echo htmlspecialchars($card['location_name']); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen p-4">
    <div class="max-w-lg mx-auto bg-white rounded-lg shadow-md overflow-hidden">
        <div class="bg-blue-600 text-white p-4">
            <h1 class="text-2xl font-bold">Add to Apple Wallet</h1>
            <p class="mt-1">Follow these steps to add your loyalty card to Apple Wallet</p>
        </div>
        
        <div class="p-6">
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Card Details</h2>
                <p><strong>Card Number:</strong> <?php echo htmlspecialchars($cardNumber); ?></p>
                <p><strong>Customer:</strong> <?php echo htmlspecialchars($card['name']); ?></p>
                <p><strong>Location:</strong> <?php echo htmlspecialchars($card['location_name']); ?></p>
                <p><strong>Stamps:</strong> <?php echo htmlspecialchars($card['stamp_count']); ?> / <?php echo htmlspecialchars($card['reward_threshold']); ?></p>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 1: Using iPhone Camera</h2>
                <p class="mb-4">Scan this QR code with your iPhone camera to open the digital card:</p>
                
                <div class="flex justify-center mb-4">
                    <img src="<?php echo $qrCodeUrl; ?>" alt="QR Code" class="border border-gray-300 rounded-lg">
                </div>
                
                <ol class="list-decimal pl-6 mb-4 space-y-2">
                    <li>Open your iPhone camera and scan the QR code</li>
                    <li>Tap the notification that appears</li>
                    <li>View your digital card in the browser</li>
                    <li>Take a screenshot by pressing the power + volume up buttons simultaneously</li>
                    <li>A thumbnail will appear in the bottom left corner, tap on it</li>
                    <li>Tap "Add to Wallet & Apple Pay" in the share menu</li>
                    <li>Follow the on-screen instructions to save to Apple Wallet</li>
                </ol>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 2: Using PassKit Web Link</h2>
                <p class="mb-4">If you're viewing this on your iPhone or iPad:</p>
                
                <ol class="list-decimal pl-6 mb-4 space-y-2">
                    <li>Take a screenshot of this page by pressing the power + volume up buttons</li>
                    <li>A thumbnail will appear in the bottom left corner, tap on it</li>
                    <li>Tap "Add to Wallet & Apple Pay" in the share menu</li>
                    <li>Follow the on-screen instructions to save to Apple Wallet</li>
                </ol>
            </div>
            
            <div class="bg-yellow-50 border border-yellow-200 rounded-lg p-4 mb-6">
                <h3 class="font-bold text-yellow-800">Note:</h3>
                <p class="text-yellow-700">Due to technical limitations, we're currently unable to generate a direct .pkpass file. The methods above provide alternative ways to add your card to Apple Wallet.</p>
            </div>
            
            <div class="mt-6 flex justify-between">
                <a href="card.php?card_number=<?php echo urlencode($cardNumber); ?>" class="px-4 py-2 bg-blue-600 text-white rounded-lg hover:bg-blue-700">
                    Back to Card
                </a>
                
                <a href="<?php echo $cardUrl; ?>" class="px-4 py-2 bg-gray-800 text-white rounded-lg hover:bg-gray-900">
                    View Digital Card
                </a>
            </div>
        </div>
    </div>
</body>
</html> 