<?php
// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

echo "<h2>PHP Extension Check</h2>";

// Required extensions for PKPass
$requiredExtensions = [
    'openssl' => 'Required for encryption/certificate handling',
    'zip' => 'Required for creating the pkpass file',
    'json' => 'Required for JSON encoding/decoding',
    'gd' => 'Required for image processing'
];

echo "<table border='1' cellpadding='5' style='border-collapse: collapse;'>";
echo "<tr><th>Extension</th><th>Status</th><th>Description</th></tr>";

$allExtensionsAvailable = true;

foreach ($requiredExtensions as $extension => $description) {
    $available = extension_loaded($extension);
    $status = $available ? '<span style="color: green;">Available</span>' : '<span style="color: red;">Not Available</span>';
    
    if (!$available) {
        $allExtensionsAvailable = false;
    }
    
    echo "<tr><td>$extension</td><td>$status</td><td>$description</td></tr>";
}

echo "</table>";

if (!$allExtensionsAvailable) {
    echo "<p style='color: red;'>One or more required extensions are missing. Please enable them in your PHP configuration.</p>";
} else {
    echo "<p style='color: green;'>All required extensions are available.</p>";
}

// Check PHP version
echo "<h3>PHP Version</h3>";
echo "Current PHP Version: " . phpversion();
echo "<br>Recommended Version: >= 7.0";

// Check openssl version if available
if (extension_loaded('openssl')) {
    echo "<h3>OpenSSL Information</h3>";
    $opensslVersion = OPENSSL_VERSION_TEXT;
    echo "OpenSSL Version: $opensslVersion";
}

// Check temp directory permissions
$tempDir = __DIR__ . '/../temp';
echo "<h3>Directory Permissions</h3>";
echo "Temp Directory: $tempDir<br>";
if (file_exists($tempDir)) {
    echo "Exists: Yes<br>";
    echo "Writable: " . (is_writable($tempDir) ? "Yes" : "No") . "<br>";
} else {
    echo "Exists: No<br>";
}

// Check if certs directory is readable
$certsDir = __DIR__ . '/../certs';
echo "Certs Directory: $certsDir<br>";
if (file_exists($certsDir)) {
    echo "Exists: Yes<br>";
    echo "Readable: " . (is_readable($certsDir) ? "Yes" : "No") . "<br>";
} else {
    echo "Exists: No<br>";
}

// Check certificate files
$p12File = $certsDir . '/Certificates.p12';
$wwdrFile = $certsDir . '/AppleWWDRMPCA1G1.cer';

echo "<h3>Certificate Files</h3>";
echo "P12 Certificate: $p12File<br>";
if (file_exists($p12File)) {
    echo "Exists: Yes<br>";
    echo "Size: " . filesize($p12File) . " bytes<br>";
    echo "Readable: " . (is_readable($p12File) ? "Yes" : "No") . "<br>";
} else {
    echo "Exists: No<br>";
}

echo "<br>WWDR Certificate: $wwdrFile<br>";
if (file_exists($wwdrFile)) {
    echo "Exists: Yes<br>";
    echo "Size: " . filesize($wwdrFile) . " bytes<br>";
    echo "Readable: " . (is_readable($wwdrFile) ? "Yes" : "No") . "<br>";
} else {
    echo "Exists: No<br>";
}

// Show installed PHP modules
echo "<h3>Installed PHP Modules</h3>";
echo "<pre>";
print_r(get_loaded_extensions());
echo "</pre>";
?> 