<?php
// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

echo "<h2>Certificate Conversion</h2>";

// Certificate paths
$certDir = __DIR__ . '/../certs/';
$p12File = $certDir . 'Certificates.p12';

// Certificate passwords
$p12Password = 'T@pple9696';  // Password for the .p12 file
$keyPassphrase = 'test';      // Passphrase used when signing the certificate

// Output paths
$signerCertPath = $certDir . 'signerCert.pem';
$signerKeyPath = $certDir . 'signerKey.pem';

echo "Converting certificates...\n\n";

// Read PKCS#12 file
if (!file_exists($p12File)) {
    die("Error: Certificates.p12 file not found\n");
}

// Convert PKCS#12 to PEM
if (!openssl_pkcs12_read(file_get_contents($p12File), $certs, $p12Password)) {
    die("Error: Failed to read PKCS#12 file: " . openssl_error_string() . "\n");
}

// Save the certificate
if (file_put_contents($signerCertPath, $certs['cert']) === false) {
    die("Error: Failed to save certificate\n");
}

// Re-encrypt the private key with the new passphrase
$privateKey = openssl_pkey_get_private($certs['pkey']);
if (!$privateKey) {
    die("Error: Failed to load private key: " . openssl_error_string() . "\n");
}

// Export the private key with the new passphrase
$success = openssl_pkey_export($privateKey, $encryptedKey, $keyPassphrase);
if (!$success) {
    die("Error: Failed to encrypt private key: " . openssl_error_string() . "\n");
}

// Save the re-encrypted private key
if (file_put_contents($signerKeyPath, $encryptedKey) === false) {
    die("Error: Failed to save private key\n");
}

// Clean up
openssl_pkey_free($privateKey);

echo "✓ Successfully converted certificates:\n";
echo "  - Signer Certificate: $signerCertPath\n";
echo "  - Private Key: $signerKeyPath (encrypted with new passphrase)\n";

// Set correct permissions
chmod($signerCertPath, 0644);
chmod($signerKeyPath, 0644);

echo "\nDone! Please run test_certificates.php to verify the conversion.\n";

// Certificate paths
$wwdrPath = __DIR__ . '/../certs/AppleWWDRMPCA1G1.cer';
$password = 'T@pple9696';

// Output paths
$pemCertPath = __DIR__ . '/../certs/certificate.pem';
$pemKeyPath = __DIR__ . '/../certs/key.pem';
$pemWWDRPath = __DIR__ . '/../certs/wwdr.pem';

echo "<h3>Original Certificate Files:</h3>";
echo "P12 Certificate: " . $p12File . " - " . (file_exists($p12File) ? "Exists" : "Not Found") . "<br>";
echo "WWDR Certificate: " . $wwdrPath . " - " . (file_exists($wwdrPath) ? "Exists" : "Not Found") . "<br>";

// Check if p12 file exists
if (!file_exists($p12File)) {
    die("P12 certificate file not found.");
}

// Check if WWDR file exists
if (!file_exists($wwdrPath)) {
    die("WWDR certificate file not found.");
}

// Try to convert P12 to PEM certificates
echo "<h3>Converting P12 Certificate to PEM format:</h3>";

// Convert P12 to PEM file using OpenSSL
$command = "openssl pkcs12 -in " . escapeshellarg($p12File) . 
           " -out " . escapeshellarg($pemCertPath) . 
           " -clcerts -nokeys -passin pass:" . escapeshellarg($password);

echo "Running command: " . htmlspecialchars($command) . "<br>";
exec($command, $output, $returnCode);

if ($returnCode !== 0) {
    echo "<p style='color: red;'>Failed to convert certificate. Return code: $returnCode</p>";
    echo "<pre>" . implode("\n", $output) . "</pre>";
} else {
    echo "<p style='color: green;'>Certificate converted successfully.</p>";
}

// Convert P12 to PEM key file
$command = "openssl pkcs12 -in " . escapeshellarg($p12File) . 
           " -out " . escapeshellarg($pemKeyPath) . 
           " -nocerts -nodes -passin pass:" . escapeshellarg($password);

echo "Running command: " . htmlspecialchars($command) . "<br>";
exec($command, $output, $returnCode);

if ($returnCode !== 0) {
    echo "<p style='color: red;'>Failed to extract private key. Return code: $returnCode</p>";
    echo "<pre>" . implode("\n", $output) . "</pre>";
} else {
    echo "<p style='color: green;'>Private key extracted successfully.</p>";
}

// Convert WWDR certificate to PEM format
$command = "openssl x509 -inform der -in " . escapeshellarg($wwdrPath) . 
           " -out " . escapeshellarg($pemWWDRPath);

echo "Running command: " . htmlspecialchars($command) . "<br>";
exec($command, $output, $returnCode);

if ($returnCode !== 0) {
    echo "<p style='color: red;'>Failed to convert WWDR certificate. Return code: $returnCode</p>";
    echo "<pre>" . implode("\n", $output) . "</pre>";
} else {
    echo "<p style='color: green;'>WWDR certificate converted successfully.</p>";
}

// Check if the converted files exist
echo "<h3>Converted Certificate Files:</h3>";
echo "PEM Certificate: " . $pemCertPath . " - " . (file_exists($pemCertPath) ? "Exists" : "Not Found") . "<br>";
echo "PEM Key: " . $pemKeyPath . " - " . (file_exists($pemKeyPath) ? "Exists" : "Not Found") . "<br>";
echo "PEM WWDR: " . $pemWWDRPath . " - " . (file_exists($pemWWDRPath) ? "Exists" : "Not Found") . "<br>";

// Provide a link to the modified PKPass script
echo "<h3>Next Steps:</h3>";
echo "<p>If the conversion was successful, you can try generating a pass using the converted certificates:</p>";
echo "<a href='generate_pkpass_pem.php?card_number=LC202503224956'>Generate PKPass with PEM certificates</a>";
?> 