<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

$basePath = realpath(dirname(__FILE__) . '/../..');
require_once($basePath . '/includes/functions.php');

// Set up HTML page
?>
<!DOCTYPE html>
<html>
<head>
    <title>PassKit Integration Test</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
        }
        .section {
            margin-bottom: 30px;
            padding: 20px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        h2 {
            margin-top: 0;
            color: #333;
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        table th, table td {
            padding: 8px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }
        form {
            margin-top: 20px;
        }
        input[type="text"] {
            padding: 8px;
            width: 200px;
        }
        button {
            padding: 8px 16px;
            background-color: #4361ee;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
        button:hover {
            background-color: #354aca;
        }
        .status {
            margin-top: 10px;
            padding: 10px;
            border-radius: 4px;
        }
        .success {
            background-color: #d4edda;
            color: #155724;
        }
        .error {
            background-color: #f8d7da;
            color: #721c24;
        }
        pre {
            background-color: #f5f5f5;
            padding: 10px;
            border-radius: 4px;
            overflow-x: auto;
        }
    </style>
</head>
<body>
    <h1>PassKit Integration Test</h1>
    
    <div class="section">
        <h2>1. Check Environment</h2>
        <?php
        // Check if required directories exist
        $certsDir = $basePath . '/certs';
        $passesDir = $basePath . '/passes';
        $logsDir = $basePath . '/logs';
        $passImagesDir = $basePath . '/assets/pass_images';
        
        $dirs = [
            'Certificates Directory' => $certsDir,
            'Passes Directory' => $passesDir,
            'Logs Directory' => $logsDir,
            'Pass Images Directory' => $passImagesDir
        ];
        
        echo '<table>';
        echo '<tr><th>Directory</th><th>Path</th><th>Status</th></tr>';
        foreach ($dirs as $name => $path) {
            $exists = is_dir($path);
            $status = $exists ? 'Exists' : 'Missing';
            $statusClass = $exists ? 'success' : 'error';
            echo "<tr><td>$name</td><td>$path</td><td class='$statusClass'>$status</td></tr>";
            
            // Create directory if missing
            if (!$exists) {
                mkdir($path, 0777, true);
                echo "<tr><td colspan='3'><em>Created directory: $path</em></td></tr>";
            }
        }
        echo '</table>';
        
        // Check necessary certificate files
        $certFiles = [
            'Signer Certificate' => $certsDir . '/signerCert.pem',
            'Signer Key' => $certsDir . '/signerKey.pem',
            'WWDR Certificate' => $certsDir . '/Apple Worldwide Developer Relations Certification Authority.pem',
            'Push Certificate' => $certsDir . '/pushCert.pem',
            'Push Key' => $certsDir . '/pushKey.pem'
        ];
        
        echo '<h3>Certificate Files</h3>';
        echo '<table>';
        echo '<tr><th>File</th><th>Path</th><th>Status</th></tr>';
        foreach ($certFiles as $name => $path) {
            $exists = file_exists($path);
            $status = $exists ? 'Exists' : 'Missing';
            $statusClass = $exists ? 'success' : 'error';
            echo "<tr><td>$name</td><td>$path</td><td class='$statusClass'>$status</td></tr>";
        }
        echo '</table>';
        
        // Check pass image files
        $passImages = [
            'icon.png', 'icon@2x.png', 
            'logo.png', 'logo@2x.png'
        ];
        
        echo '<h3>Pass Images</h3>';
        echo '<table>';
        echo '<tr><th>Image</th><th>Path</th><th>Status</th></tr>';
        foreach ($passImages as $image) {
            $path = $passImagesDir . '/' . $image;
            $exists = file_exists($path);
            $status = $exists ? 'Exists' : 'Missing';
            $statusClass = $exists ? 'success' : 'error';
            echo "<tr><td>$image</td><td>$path</td><td class='$statusClass'>$status</td></tr>";
        }
        echo '</table>';
        ?>
    </div>
    
    <div class="section">
        <h2>2. Database Tables</h2>
        <?php
        // Check if database tables exist
        $conn = getDbConnection();
        $tables = [
            'loyalty_cards',
            'pass_registrations',
            'pass_updates',
            'loyalty_card_logs'
        ];
        
        echo '<table>';
        echo '<tr><th>Table</th><th>Status</th><th>Count</th></tr>';
        foreach ($tables as $table) {
            try {
                $stmt = $conn->prepare("SHOW TABLES LIKE ?");
                $stmt->execute([$table]);
                $exists = $stmt->rowCount() > 0;
                
                $count = 0;
                if ($exists) {
                    $countStmt = $conn->prepare("SELECT COUNT(*) as count FROM $table");
                    $countStmt->execute();
                    $result = $countStmt->fetch(PDO::FETCH_ASSOC);
                    $count = $result['count'];
                }
                
                $status = $exists ? 'Exists' : 'Missing';
                $statusClass = $exists ? 'success' : 'error';
                echo "<tr><td>$table</td><td class='$statusClass'>$status</td><td>$count</td></tr>";
            } catch (Exception $e) {
                echo "<tr><td>$table</td><td class='error'>Error</td><td>{$e->getMessage()}</td></tr>";
            }
        }
        echo '</table>';
        
        // Show registrations if they exist
        try {
            $stmt = $conn->prepare("SELECT * FROM pass_registrations LIMIT 10");
            $stmt->execute();
            $registrations = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            if (count($registrations) > 0) {
                echo '<h3>Pass Registrations</h3>';
                echo '<table>';
                echo '<tr><th>ID</th><th>Pass ID</th><th>Device ID</th><th>Push Token</th></tr>';
                foreach ($registrations as $reg) {
                    echo "<tr><td>{$reg['id']}</td><td>{$reg['pass_id']}</td><td>{$reg['device_id']}</td><td>{$reg['push_token']}</td></tr>";
                }
                echo '</table>';
            }
        } catch (Exception $e) {
            echo "<p class='error'>Error fetching registrations: {$e->getMessage()}</p>";
        }
        ?>
    </div>
    
    <div class="section">
        <h2>3. Generate Test Pass</h2>
        <form method="post" action="">
            <input type="text" name="card_number" placeholder="Enter Card Number" required>
            <button type="submit" name="generate_pass">Generate Pass</button>
        </form>
        
        <?php
        if (isset($_POST['generate_pass'])) {
            $cardNumber = $_POST['card_number'];
            
            try {
                // Fetch card details
                $stmt = $conn->prepare("
                    SELECT lc.*, c.name, c.email, l.name as location_name, l.logo_url, l.reward_threshold, l.reward_description
                    FROM loyalty_cards lc
                    JOIN customers c ON lc.customer_id = c.id
                    JOIN locations l ON c.location_id = l.id
                    WHERE lc.card_number = ?
                ");
                $stmt->execute([$cardNumber]);
                $card = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if (!$card) {
                    echo "<div class='status error'>Card not found: $cardNumber</div>";
                } else {
                    // Redirect to the generate_pass.php script
                    echo "<div class='status success'>Card found: {$card['name']} ({$cardNumber})</div>";
                    echo "<p>Generating pass...</p>";
                    echo "<script>window.location.href = '../generate_pass.php?card_number=$cardNumber';</script>";
                }
            } catch (Exception $e) {
                echo "<div class='status error'>Error: {$e->getMessage()}</div>";
            }
        }
        ?>
    </div>
    
    <div class="section">
        <h2>4. Test Push Updates</h2>
        <form method="post" action="">
            <input type="text" name="push_card_number" placeholder="Enter Card Number" required>
            <button type="submit" name="push_update">Push Update</button>
        </form>
        
        <?php
        if (isset($_POST['push_update'])) {
            $cardNumber = $_POST['push_card_number'];
            
            // Update database first
            try {
                $conn = getDbConnection();
                
                // Check if card exists
                $stmt = $conn->prepare("SELECT * FROM loyalty_cards WHERE card_number = ?");
                $stmt->execute([$cardNumber]);
                $card = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if (!$card) {
                    echo "<div class='status error'>Card not found: $cardNumber</div>";
                } else {
                    // Make a request to the push.php file
                    $pushUrl = 'http://' . $_SERVER['HTTP_HOST'] . dirname($_SERVER['REQUEST_URI']) . '/push.php';
                    $data = json_encode(['card_number' => $cardNumber]);
                    
                    $ch = curl_init($pushUrl);
                    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
                    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                    curl_setopt($ch, CURLOPT_HTTPHEADER, [
                        'Content-Type: application/json',
                        'Content-Length: ' . strlen($data)
                    ]);
                    
                    $result = curl_exec($ch);
                    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                    curl_close($ch);
                    
                    if ($httpCode == 200) {
                        echo "<div class='status success'>Push notification sent!</div>";
                        echo "<pre>" . htmlspecialchars($result) . "</pre>";
                    } else {
                        echo "<div class='status error'>Error sending push (HTTP Code: $httpCode)</div>";
                        echo "<pre>" . htmlspecialchars($result) . "</pre>";
                    }
                }
            } catch (Exception $e) {
                echo "<div class='status error'>Error: {$e->getMessage()}</div>";
            }
        }
        ?>
    </div>
    
    <div class="section">
        <h2>5. System Information</h2>
        <?php
        echo '<h3>PHP Extensions</h3>';
        echo '<table>';
        $requiredExtensions = ['curl', 'zip', 'openssl', 'pdo', 'pdo_mysql'];
        foreach ($requiredExtensions as $ext) {
            $loaded = extension_loaded($ext);
            $status = $loaded ? 'Loaded' : 'Not Loaded';
            $statusClass = $loaded ? 'success' : 'error';
            echo "<tr><td>$ext</td><td class='$statusClass'>$status</td></tr>";
        }
        echo '</table>';
        
        echo '<h3>Server Information</h3>';
        echo '<table>';
        echo '<tr><td>PHP Version</td><td>' . phpversion() . '</td></tr>';
        echo '<tr><td>Server Software</td><td>' . $_SERVER['SERVER_SOFTWARE'] . '</td></tr>';
        echo '<tr><td>HTTP Host</td><td>' . $_SERVER['HTTP_HOST'] . '</td></tr>';
        echo '<tr><td>Script Path</td><td>' . $_SERVER['SCRIPT_NAME'] . '</td></tr>';
        echo '<tr><td>Web Service URL</td><td>https://' . $_SERVER['HTTP_HOST'] . dirname(dirname($_SERVER['REQUEST_URI'])) . '/passkit/</td></tr>';
        echo '</table>';
        
        echo '<h3>Log Files</h3>';
        echo '<table>';
        $logFiles = [
            'Register Log' => $logsDir . '/passkit_register.log',
            'Push Log' => $logsDir . '/passkit_push.log',
            'Passes Log' => $logsDir . '/passkit_passes.log'
        ];
        
        foreach ($logFiles as $name => $path) {
            $exists = file_exists($path);
            $size = $exists ? filesize($path) : 0;
            $status = $exists ? "Exists ($size bytes)" : 'Not created yet';
            $statusClass = $exists ? 'success' : 'error';
            echo "<tr><td>$name</td><td>$path</td><td class='$statusClass'>$status</td></tr>";
        }
        echo '</table>';
        ?>
    </div>
</body>
</html> 