<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Check each step of pass creation
echo "<h1>Testing Pass Generation Process</h1>";

// Step 1: Check certificate files
$certDir = __DIR__ . '/../certs/';
$signerCertPath = $certDir . 'signerCert.pem';
$signerKeyPath = $certDir . 'signerKey.pem';
$wwdrCertPath = $certDir . 'Apple Worldwide Developer Relations Certification Authority.pem';
$keyPassphrase = 'test';

echo "<h2>Step 1: Certificate Check</h2>";
echo "Signer Cert: " . (file_exists($signerCertPath) ? "✅ Found" : "❌ Not found") . "<br>";
echo "Signer Key: " . (file_exists($signerKeyPath) ? "✅ Found" : "❌ Not found") . "<br>";
echo "WWDR Cert: " . (file_exists($wwdrCertPath) ? "✅ Found" : "❌ Not found") . "<br>";

// Step 2: Check certificate readability
echo "<h2>Step 2: Certificate Readability</h2>";
echo "Signer Cert readable: " . (is_readable($signerCertPath) ? "✅ Yes" : "❌ No") . "<br>";
echo "Signer Key readable: " . (is_readable($signerKeyPath) ? "✅ Yes" : "❌ No") . "<br>";
echo "WWDR Cert readable: " . (is_readable($wwdrCertPath) ? "✅ Yes" : "❌ No") . "<br>";

// Step 3: Test private key decryption
echo "<h2>Step 3: Private Key Test</h2>";
try {
    $pkeyData = file_get_contents($signerKeyPath);
    $privateKey = openssl_pkey_get_private($pkeyData, $keyPassphrase);
    if ($privateKey) {
        echo "✅ Successfully loaded private key<br>";
        openssl_pkey_free($privateKey);
    } else {
        echo "❌ Failed to load private key: " . openssl_error_string() . "<br>";
    }
} catch (Exception $e) {
    echo "❌ Exception: " . $e->getMessage() . "<br>";
}

// Step 4: Check pass template directory
$passDir = __DIR__ . '/../passes/';
$passTemplateDir = $passDir . 'templates/loyalty/';
$tmpDir = $passDir . 'tmp/';

echo "<h2>Step 4: Template Directory Check</h2>";
echo "Template directory exists: " . (is_dir($passTemplateDir) ? "✅ Yes" : "❌ No") . "<br>";
echo "Template directory readable: " . (is_readable($passTemplateDir) ? "✅ Yes" : "❌ No") . "<br>";
echo "pass.json exists: " . (file_exists($passTemplateDir . 'pass.json') ? "✅ Yes" : "❌ No") . "<br>";

// Step 5: Check temp directory
echo "<h2>Step 5: Temporary Directory Check</h2>";
echo "Temp directory exists: " . (is_dir($tmpDir) ? "✅ Yes" : "❌ No") . "<br>";
echo "Temp directory writable: " . (is_writable($tmpDir) ? "✅ Yes" : "❌ No") . "<br>";

// Step 6: Check pass directory for writing .pkpass files
echo "<h2>Step 6: Pass Directory Write Check</h2>";
echo "Pass directory exists: " . (is_dir($passDir) ? "✅ Yes" : "❌ No") . "<br>";
echo "Pass directory writable: " . (is_writable($passDir) ? "✅ Yes" : "❌ No") . "<br>";

// Step 7: Test creating a test file in the temp directory
echo "<h2>Step 7: File Creation Test</h2>";
$testTmpDir = $tmpDir . 'test_' . uniqid();
$testResult = @mkdir($testTmpDir, 0777, true);
echo "Creating test directory: " . ($testResult ? "✅ Success" : "❌ Failed") . "<br>";
if ($testResult) {
    $testFile = $testTmpDir . '/test.txt';
    $writeResult = @file_put_contents($testFile, 'Test content');
    echo "Writing test file: " . ($writeResult !== false ? "✅ Success" : "❌ Failed") . "<br>";
    
    // Clean up
    @unlink($testFile);
    @rmdir($testTmpDir);
}

echo "<h2>Conclusion</h2>";
echo "If all checks above show green checkmarks, your setup should be working.<br>";
echo "If any show red X's, those are areas that need to be fixed.<br>";
echo "<br><a href='test_wallet.php'>Return to Test Wallet Page</a>";
?> 