<?php
require_once '../includes/functions.php';

// Get card numbers from the database to test
$conn = getDbConnection();
$stmt = $conn->query("
    SELECT lc.card_number, c.name, l.name as location_name 
    FROM loyalty_cards lc
    JOIN customers c ON lc.customer_id = c.id
    JOIN locations l ON c.location_id = l.id
    LIMIT 5
");
$cards = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Test Apple Wallet Integration</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen p-6">
    <div class="max-w-2xl mx-auto bg-white rounded-lg shadow-md p-6">
        <h1 class="text-2xl font-bold mb-6">Test Apple Wallet Integration</h1>
        
        <div class="mb-6">
            <p class="text-gray-700 mb-4">This page allows you to test the integration with Apple Wallet. Click on any card to generate and download the .pkpass file.</p>
        </div>
        
        <div class="space-y-4">
            <h2 class="text-xl font-semibold">Available Test Cards</h2>
            
            <?php if (empty($cards)): ?>
            <p class="text-red-500">No loyalty cards found in the database.</p>
            <?php else: ?>
                <div class="space-y-3">
                <?php foreach ($cards as $card): ?>
                    <div class="flex items-center justify-between p-4 border rounded-lg bg-gray-50 hover:bg-gray-100">
                        <div>
                            <div class="font-medium"><?php echo htmlspecialchars($card['name']); ?></div>
                            <div class="text-sm text-gray-500"><?php echo htmlspecialchars($card['location_name']); ?> - <?php echo htmlspecialchars($card['card_number']); ?></div>
                        </div>
                        <div class="flex space-x-3">
                            <a href="card.php?card_number=<?php echo urlencode($card['card_number']); ?>" class="px-4 py-2 bg-blue-600 text-white rounded hover:bg-blue-700">View Card</a>
                            <a href="generate_pass.php?card_number=<?php echo urlencode($card['card_number']); ?>" class="px-4 py-2 bg-black text-white rounded hover:bg-gray-800">Add to Apple Wallet</a>
                        </div>
                    </div>
                <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        
        <div class="mt-8 p-4 bg-yellow-50 border border-yellow-200 rounded-lg">
            <h3 class="font-semibold text-yellow-700">Notes:</h3>
            <ul class="list-disc pl-5 mt-2 text-yellow-700">
                <li>When testing on iOS devices, you should see the "Add to Apple Wallet" option after downloading the .pkpass file</li>
                <li>Make sure you're using Safari on iOS for best compatibility</li>
                <li>If testing on desktop, you can download the .pkpass file and open it with the Wallet app on macOS</li>
            </ul>
        </div>
    </div>
</body>
</html> 