<?php
// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

echo "<h2>Certificate Verification</h2>";

// Certificate information
$certificatePath = __DIR__ . '/../certs/Certificates.p12';
$certificatePassword = 'T@pple9696';

// Check if certificate file exists
if (!file_exists($certificatePath)) {
    die("Certificate file not found at: $certificatePath");
}

echo "Certificate file found at: $certificatePath<br>";
echo "File size: " . filesize($certificatePath) . " bytes<br>";

// Try to read the certificate using OpenSSL
echo "<h3>Attempting to verify certificate password</h3>";

try {
    // Try to read the PKCS12 file
    $result = openssl_pkcs12_read(file_get_contents($certificatePath), $certs, $certificatePassword);
    
    if ($result) {
        echo "<p style='color: green;'>✓ Success! Certificate password is correct.</p>";
        
        echo "<h3>Certificate Contents</h3>";
        echo "<p>Certificate contains the following keys:</p>";
        echo "<ul>";
        foreach (array_keys($certs) as $key) {
            echo "<li>" . htmlspecialchars($key) . "</li>";
        }
        echo "</ul>";
        
        // Check if it has a private key
        if (isset($certs['pkey'])) {
            echo "<p style='color: green;'>✓ Certificate contains a private key.</p>";
        } else {
            echo "<p style='color: red;'>✗ Certificate does not contain a private key!</p>";
        }
    } else {
        echo "<p style='color: red;'>✗ Failed to read certificate. Password may be incorrect.</p>";
        echo "<p>OpenSSL Error: " . openssl_error_string() . "</p>";
        
        // Try alternative password formats
        $alternativePasswords = [
            'T@pple9696', // Original
            'Tapple9696', // Without special character
            't@pple9696', // Lowercase T
            'T@PPLE9696', // All uppercase
            '@pple9696', // Without T
            'T@pple', // Without numbers
            '9696', // Just numbers
            '' // Empty password
        ];
        
        echo "<h3>Trying alternative passwords:</h3>";
        echo "<ul>";
        
        foreach ($alternativePasswords as $altPassword) {
            if ($altPassword === $certificatePassword) {
                continue; // Skip the original password as we already tried it
            }
            
            $altResult = openssl_pkcs12_read(file_get_contents($certificatePath), $altCerts, $altPassword);
            
            if ($altResult) {
                echo "<li style='color: green;'>Password '<strong>" . htmlspecialchars($altPassword) . "</strong>' works!</li>";
            } else {
                echo "<li style='color: red;'>Password '" . htmlspecialchars($altPassword) . "' failed.</li>";
            }
        }
        
        echo "</ul>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>Exception: " . $e->getMessage() . "</p>";
}

// Try to verify the certificate file format
echo "<h3>Certificate File Format Check</h3>";

$fileContent = file_get_contents($certificatePath);
$fileHeader = bin2hex(substr($fileContent, 0, 4));

echo "File header (first 4 bytes): " . $fileHeader . "<br>";

// PKCS#12 files typically start with 30 82
if (substr($fileHeader, 0, 4) === '3082') {
    echo "<p style='color: green;'>✓ File appears to be a valid PKCS#12 format.</p>";
} else {
    echo "<p style='color: red;'>✗ File does not appear to be a valid PKCS#12 format!</p>";
}

// Suggest a way forward
echo "<h3>Next Steps</h3>";
echo "<p>If the certificate verification failed, you may need to:</p>";
echo "<ol>";
echo "<li>Check the certificate password - make sure it's exactly correct, including case and special characters.</li>";
echo "<li>Re-export the certificate from Apple Developer Portal with a known password.</li>";
echo "<li>Make sure the certificate file was not corrupted during transfer.</li>";
echo "<li>Verify that the certificate contains a private key.</li>";
echo "</ol>";
?> 