<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

echo "<h1>Apple Wallet Certificate Verification</h1>";

// Check OpenSSL version
echo "<h2>OpenSSL Version</h2>";
echo "<p>" . OPENSSL_VERSION_TEXT . "</p>";

// Check required PHP extensions
echo "<h2>Required Extensions</h2>";
$requiredExtensions = ['openssl', 'zip', 'json'];
foreach ($requiredExtensions as $ext) {
    if (extension_loaded($ext)) {
        echo "<p style='color: green'>✓ $ext extension is loaded</p>";
    } else {
        echo "<p style='color: red'>✗ $ext extension is NOT loaded</p>";
    }
}

// Check certificate paths
echo "<h2>Certificate Paths</h2>";
$certDir = __DIR__ . '/../certs/';
$signerCertPath = $certDir . 'signerCert.pem';
$signerKeyPath = $certDir . 'signerKey.pem';
$wwdrCertPath = $certDir . 'Apple Worldwide Developer Relations Certification Authority.pem';
$keyPassphrase = 'test'; // The passphrase from your script

if (file_exists($signerCertPath)) {
    echo "<p style='color: green'>✓ Signer certificate exists at: $signerCertPath</p>";
    $certContent = file_get_contents($signerCertPath);
    $certInfo = openssl_x509_parse($certContent);
    if ($certInfo) {
        echo "<p style='color: green'>✓ Signer certificate is valid</p>";
        echo "<pre>" . print_r($certInfo, true) . "</pre>";
    } else {
        echo "<p style='color: red'>✗ Signer certificate is NOT valid: " . openssl_error_string() . "</p>";
    }
} else {
    echo "<p style='color: red'>✗ Signer certificate NOT found at: $signerCertPath</p>";
}

if (file_exists($signerKeyPath)) {
    echo "<p style='color: green'>✓ Signer key exists at: $signerKeyPath</p>";
    $pkeyid = @openssl_pkey_get_private(file_get_contents($signerKeyPath), $keyPassphrase);
    if ($pkeyid) {
        echo "<p style='color: green'>✓ Signer key is valid and password is correct</p>";
    } else {
        echo "<p style='color: red'>✗ Signer key is NOT valid or wrong password: " . openssl_error_string() . "</p>";
    }
} else {
    echo "<p style='color: red'>✗ Signer key NOT found at: $signerKeyPath</p>";
}

if (file_exists($wwdrCertPath)) {
    echo "<p style='color: green'>✓ WWDR certificate exists at: $wwdrCertPath</p>";
    $certContent = file_get_contents($wwdrCertPath);
    $certInfo = openssl_x509_parse($certContent);
    if ($certInfo) {
        echo "<p style='color: green'>✓ WWDR certificate is valid</p>";
    } else {
        echo "<p style='color: red'>✗ WWDR certificate is NOT valid: " . openssl_error_string() . "</p>";
    }
} else {
    echo "<p style='color: red'>✗ WWDR certificate NOT found at: $wwdrCertPath</p>";
}

echo "<h2>Recommendations</h2>";
echo "<p>If you're having issues with your .pkpass files:</p>";
echo "<ol>";
echo "<li>Ensure your certificates are in PEM format</li>";
echo "<li>Make sure your Pass Type ID matches what's registered in your Apple Developer account</li>";
echo "<li>Check that your Team Identifier is correct</li>";
echo "<li>Verify your certificate password is correct</li>";
echo "<li>Try regenerating the pass with different barcode formats</li>";
echo "<li>Test on multiple iOS devices or simulators</li>";
echo "</ol>";

echo "<p><a href='generate_pass.php?card_number=LC202503224956'>Try generating a test pass</a></p>"; 