<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include database connection
$includePath = dirname(__FILE__) . '/../includes/functions.php';
require_once($includePath);

// Create pass_registrations table
$conn = getDbConnection();
try {
    // Check if table already exists
    $stmt = $conn->prepare("
        SELECT COUNT(*) as count 
        FROM information_schema.tables 
        WHERE table_schema = DATABASE() 
        AND table_name = 'pass_registrations'
    ");
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($result['count'] > 0) {
        echo "Table pass_registrations already exists.<br>";
    } else {
        // Create the table
        $sql = "
            CREATE TABLE pass_registrations (
                id INT AUTO_INCREMENT PRIMARY KEY,
                device_library_identifier VARCHAR(255) NOT NULL,
                pass_type_identifier VARCHAR(255) NOT NULL,
                serial_number VARCHAR(255) NOT NULL,
                push_token VARCHAR(255) NOT NULL,
                created_at DATETIME NOT NULL,
                updated_at DATETIME NOT NULL,
                UNIQUE KEY unique_registration (device_library_identifier, pass_type_identifier, serial_number)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
        ";
        
        $conn->exec($sql);
        echo "Table pass_registrations created successfully.<br>";
    }
    
    // Check if the loyalty_cards table has the updated_at column
    $stmt = $conn->prepare("
        SELECT COUNT(*) as count 
        FROM information_schema.columns 
        WHERE table_schema = DATABASE() 
        AND table_name = 'loyalty_cards' 
        AND column_name = 'updated_at'
    ");
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($result['count'] > 0) {
        echo "Column updated_at already exists in loyalty_cards table.<br>";
    } else {
        // Add updated_at column to loyalty_cards table
        $sql = "ALTER TABLE loyalty_cards ADD COLUMN updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP";
        $conn->exec($sql);
        echo "Column updated_at added to loyalty_cards table.<br>";
    }
    
    echo "Setup completed successfully.";
} catch(PDOException $e) {
    echo "Error: " . $e->getMessage();
}
?> 