<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include database connection
require_once('includes/functions.php');

// Check if card number is provided
if (!isset($_GET['card_number']) || empty($_GET['card_number'])) {
    die('Card number is required as a GET parameter');
}

$cardNumber = $_GET['card_number'];

// Get the card and related info
$conn = getDbConnection();
$stmt = $conn->prepare("
    SELECT lc.*, c.name, c.email, l.name as location_name, l.reward_threshold
    FROM loyalty_cards lc
    JOIN customers c ON lc.customer_id = c.id
    JOIN locations l ON c.location_id = l.id
    WHERE lc.card_number = :card_number
");
$stmt->bindParam(':card_number', $cardNumber);
$stmt->execute();
$card = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$card) {
    die('Card not found: ' . htmlspecialchars($cardNumber));
}

// Current stamp count
echo "Current stamp count: " . $card['stamp_count'] . "<br>";

// Update the stamp count
$newStampCount = $card['stamp_count'] + 1;
if ($newStampCount >= $card['reward_threshold']) {
    $newStampCount = 0;
}

$stmt = $conn->prepare("
    UPDATE loyalty_cards 
    SET stamp_count = :stamp_count,
        updated_at = NOW()
    WHERE card_number = :card_number
");
$stmt->bindParam(':stamp_count', $newStampCount);
$stmt->bindParam(':card_number', $cardNumber);
$result = $stmt->execute();

if (!$result) {
    die('Failed to update card');
}

// Delete current pass file to force regeneration
$passFile = __DIR__ . '/passes/' . $cardNumber . '.pkpass';
if (file_exists($passFile)) {
    unlink($passFile);
    echo "Deleted existing pass file<br>";
}

// Send push notification
require_once('includes/send_push_notification.php');
$notificationResult = sendPushNotifications($cardNumber);

echo "Card updated! New stamp count: " . $newStampCount . "<br>";
echo "Push notification result: " . ($notificationResult ? 'Success' : 'Failed') . "<br>";
echo "<p>The next time you view this card in Apple Wallet, it should update with the new stamp count.</p>";
echo "<p><a href='customer/card.php?card_number=" . urlencode($cardNumber) . "'>View card</a></p>";
?> 